Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1323)

Unified Diff: ui/base/text/text_elider.cc

Issue 9808101: Revert 128753 - Add full support for filesystem URLs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/base/net_util.cc ('k') | webkit/appcache/appcache_interfaces.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/base/text/text_elider.cc
===================================================================
--- ui/base/text/text_elider.cc (revision 128756)
+++ ui/base/text/text_elider.cc (working copy)
@@ -225,8 +225,8 @@
if (available_pixel_width <= 0)
return url_string;
- // If non-standard, return plain eliding.
- if (!url.IsStandard())
+ // If non-standard or not file type, return plain eliding.
+ if (!(url.SchemeIsFile() || url.IsStandard()))
return ElideText(url_string, font, available_pixel_width, ELIDE_AT_END);
// Now start eliding url_string to fit within available pixel width.
« no previous file with comments | « net/base/net_util.cc ('k') | webkit/appcache/appcache_interfaces.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698